pub struct ShapeWarning {
pub path: FieldPath,
pub message: String,
}Expand description
A soft check that passed but may indicate misconfiguration.
Fields
path: FieldPathmessage: StringTrait Implementations
Sourceimpl Clone for ShapeWarning
impl Clone for ShapeWarning
Sourcefn clone(&self) -> ShapeWarning
fn clone(&self) -> ShapeWarning
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ShapeWarning
impl Debug for ShapeWarning
Sourceimpl Display for ShapeWarning
impl Display for ShapeWarning
Sourceimpl PartialEq for ShapeWarning
impl PartialEq for ShapeWarning
Sourcefn eq(&self, other: &ShapeWarning) -> bool
fn eq(&self, other: &ShapeWarning) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ShapeWarning